Python API Documentation
========================

This section contains the Python API documentation for the PolytopeWalk library.

Module: polytopewalk
---------------------

.. automodule:: polytopewalk
   :members:
   :undoc-members:
   :show-inheritance:

Initialization Classes
--------

.. autoclass:: polytopewalk.FacialReduction
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: polytopewalk.dense.DenseCenter
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: polytopewalk.sparse.SparseCenter
   :members:
   :undoc-members:
   :show-inheritance:

RandomWalk Classes
-------------------

.. autoclass:: polytopewalk.dense.RandomWalk
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: polytopewalk.sparse.SparseRandomWalk
   :members:
   :undoc-members:
   :show-inheritance:

Subclasses of RandomWalk
------------------------

.. autoclass:: polytopewalk.dense.BarrierWalk
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: polytopewalk.dense.DikinWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.dense.VaidyaWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.dense.JohnWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.dense.DikinLSWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.dense.BallWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.dense.HitAndRun
   :members:
   :undoc-members:

Subclasses of SparseRandomWalk
------------------------

.. autoclass:: polytopewalk.sparse.SparseBarrierWalk
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: polytopewalk.sparse.SparseDikinWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.sparse.SparseVaidyaWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.sparse.SparseJohnWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.sparse.SparseDikinLSWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.sparse.SparseBallWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.sparse.SparseHitAndRun
   :members:
   :undoc-members: